import { __decorate } from "tslib";
import { attr, customElement, FASTElement } from '@microsoft/fast-element';
import { EventName } from '../design-system-editor/design-system-editor';
import { DesignSystemExportStyles as styles } from './design-system-export.styles';
import { DesignSystemExportTemplate as template } from './design-system-export.template';
let DesignSystemExport = class DesignSystemExport extends FASTElement {
    constructor() {
        super(...arguments);
        this.formatValues = (detail) => {
            const space = 3;
            const designTokensConfig = {
                design_tokens: {
                    color: {
                        accent: {
                            $value: detail.accentColor,
                            $type: 'color',
                        },
                        neutral: {
                            $value: detail.neutralColor,
                            $type: 'color',
                        },
                    },
                    fontFamily: {
                        bodyFont: {
                            $value: detail.bodyFont,
                            $type: 'fontFamily',
                        },
                    },
                    mode: {
                        luminance: {
                            $value: detail.luminance,
                            $type: 'number',
                        },
                    },
                    style: {
                        density: {
                            $value: detail.density,
                            $type: 'number',
                        },
                        borderRadius: {
                            $value: detail.borderRadius,
                            $type: 'number',
                        },
                        strokeWidth: {
                            $value: detail.strokeWidth,
                            $type: 'number',
                        },
                    },
                    space: {
                        designUnit: {
                            $value: detail.designUnit,
                            $type: 'number',
                        },
                    },
                },
            };
            return JSON.stringify(designTokensConfig, null, space);
        };
        this.showModal = () => {
            return this.modal.show();
        };
        this.closeModal = () => {
            return this.modal.close();
        };
    }
    connectedCallback() {
        super.connectedCallback();
        document.body.addEventListener(EventName.STYLES_CHANGED, (event) => {
            const customEvent = event;
            this.value = this.formatValues(customEvent.detail);
        });
    }
};
__decorate([
    attr
], DesignSystemExport.prototype, "value", void 0);
DesignSystemExport = __decorate([
    customElement({
        name: 'design-system-export',
        template,
        styles,
    })
], DesignSystemExport);
export { DesignSystemExport };
