import { __decorate } from "tslib";
import { parseColorHexRGB } from '@microsoft/fast-colors';
import { SwatchRGB, PaletteRGB } from '@microsoft/fast-components';
import { baseLayerLuminance, neutralPalette, accentPalette, density, controlCornerRadius, strokeWidth, designUnit, bodyFont, } from '@microsoft/fast-components';
import { attr, customElement, DOM, FASTElement, observable } from '@microsoft/fast-element';
import { EventName } from '../design-system-editor';
import { DesignSystemPreviewStyles as styles } from './design-system-preview.styles';
import { DesignSystemPreviewTemplate as template } from './design-system-preview.template';
let DesignSystemPreview = class DesignSystemPreview extends FASTElement {
    constructor() {
        super(...arguments);
        this.prefix = 'zero';
        this.buttonAppearanceAccent = 'primary-blue';
        this.buttonAppearanceNeutral = 'primary-grey';
        this.buttonAppearanceOutline = 'primary-gradient';
        this.rowData = [
            { make: 'Toyota', model: 'Celica', price: 35000, creationDate: 1617624494293, isCool: true },
            { make: 'Ford', model: 'Mondeo', price: 32000, creationDate: 1617624494295, isCool: false },
            { make: 'Porsche', model: 'Boxter', price: 72000, creationDate: 1619637452397, isCool: false },
            { make: 'Audi', model: 'A6', price: 80000, creationDate: 1617624494293, isCool: true },
            { make: 'Renault', model: 'Clio', price: 20000, creationDate: 1617624494295, isCool: true },
            {
                make: 'Chevrolet',
                model: 'Camaro',
                price: 40000,
                creationDate: 1619637452397,
                isCool: false,
            },
            { make: 'BMW', model: 'Z8', price: 90000, creationDate: 1617624494293, isCool: false },
            { make: 'Suzuki', model: 'Jimny', price: 23000, creationDate: 1617624494295, isCool: false },
            { make: 'Toyota', model: 'Celica', price: 35000, creationDate: 1619637452397, isCool: true },
            { make: 'Ford', model: 'Mondeo', price: 32000, creationDate: 1617624494293, isCool: false },
            { make: 'Porsche', model: 'Boxter', price: 72000, creationDate: 1617624494295, isCool: true },
            { make: 'Audi', model: 'A6', price: 80000, creationDate: 1619637452397, isCool: false },
            { make: 'Renault', model: 'Clio', price: 20000, creationDate: 1617624494293, isCool: false },
            { make: 'Chevrolet', model: 'Camaro', price: 40000, creationDate: 1617624494295, isCool: true },
            { make: 'BMW', model: 'Z8', price: 90000, creationDate: 1619637452397, isCool: true },
            { make: 'Suzuki', model: 'Jimny', price: 23000, creationDate: 1617624494293, isCool: true },
        ];
        this.columnDefs = [
            { field: 'make' },
            { field: 'model' },
            { field: 'price' },
            { field: 'creationDate' },
            { field: 'isCool' },
        ];
        this.gridOptions = {
            defaultColDef: {
                resizable: true,
                filter: true,
            },
            debug: false,
            columnDefs: this.columnDefs,
            rowData: this.rowData,
        };
    }
    setGridOptions() {
        this.grid.gridOptions = this.gridOptions;
    }
    setDialogEventListeners() {
        this.showDialogTrigger.addEventListener('click', () => this.modal.show(), {
            passive: true,
        });
        this.closeDialogTrigger.addEventListener('click', () => this.modal.close(), {
            passive: true,
        });
    }
    connectedCallback() {
        super.connectedCallback();
        document.body.addEventListener(EventName.STYLES_CHANGED, (e) => {
            this.handleStyleChanges(e);
        });
        document.body.addEventListener(EventName.DS_CHANGED, (e) => {
            this.handleDSChanges(e);
        });
        this.setGridOptions();
        this.setDialogEventListeners();
        DOM.queueUpdate(() => {
            bodyFont.withDefault('"Segoe UI", Arial, Helvetica, sans-serif');
        });
    }
    handleStyleChanges(e) {
        const detail = e.detail;
        if (detail) {
            DOM.queueUpdate(() => {
                this.applyStyleChanges(detail);
            });
        }
    }
    applyStyleChanges(detail) {
        const neutral = this.paletteFromColor(detail.neutralColor);
        neutralPalette.setValueFor(this.provider, neutral);
        const accent = this.paletteFromColor(detail.accentColor);
        accentPalette.setValueFor(this.provider, accent);
        baseLayerLuminance.setValueFor(this.provider, detail.luminance);
        density.setValueFor(this.provider, detail.density);
        controlCornerRadius.setValueFor(this.provider, detail.borderRadius);
        strokeWidth.setValueFor(this.provider, detail.strokeWidth);
        designUnit.setValueFor(this.provider, detail.designUnit);
        bodyFont.setValueFor(this.provider, detail.bodyFont);
    }
    handleDSChanges(event) {
        this.prefix = event.detail.prefix;
        this.buttonAppearanceAccent = event.detail.buttonAppearanceAccent;
        this.buttonAppearanceNeutral = event.detail.buttonAppearanceNeutral;
        this.buttonAppearanceOutline = event.detail.buttonAppearanceOutline;
        DOM.queueUpdate(() => {
            this.setGridOptions();
            this.setDialogEventListeners();
        });
    }
    swatchFromColor(hexColor) {
        const color = parseColorHexRGB(hexColor);
        if (color) {
            return SwatchRGB.from(color);
        }
        return null;
    }
    paletteFromColor(hexColor) {
        const swatch = this.swatchFromColor(hexColor);
        if (swatch) {
            return PaletteRGB.create(swatch);
        }
        return null;
    }
};
__decorate([
    observable
], DesignSystemPreview.prototype, "grid", void 0);
__decorate([
    attr
], DesignSystemPreview.prototype, "prefix", void 0);
__decorate([
    observable
], DesignSystemPreview.prototype, "buttonAppearanceAccent", void 0);
__decorate([
    observable
], DesignSystemPreview.prototype, "buttonAppearanceNeutral", void 0);
__decorate([
    observable
], DesignSystemPreview.prototype, "buttonAppearanceOutline", void 0);
__decorate([
    observable
], DesignSystemPreview.prototype, "provider", void 0);
__decorate([
    observable
], DesignSystemPreview.prototype, "rowData", void 0);
__decorate([
    observable
], DesignSystemPreview.prototype, "columnDefs", void 0);
__decorate([
    observable
], DesignSystemPreview.prototype, "gridOptions", void 0);
DesignSystemPreview = __decorate([
    customElement({
        name: 'design-system-preview',
        template,
        styles,
    })
], DesignSystemPreview);
export { DesignSystemPreview };
